import { astroBuildDone } from "./hooks/index.js";
import { fileURLToPath } from "node:url";
/**
 * Transpiles inline scripts using Babel.
 *
 * [Read more](https://www.npmjs.com/package/astro-babel-inline-scripts)
 * @param options Object with a configuration for Babel.
 * @param routeCallback Optional callback which gets called per a route. Return `false` to exclude a route from processing.
 */
export default ((options) => {
    let outDir
    return {
        name: "babel-inline-scripts",
        hooks: {
            "astro:config:setup": ({ config }) => {
                if (config.output === "server") {
                    console.warn(
                        "Output type `server` does not produce static *.html pages in its output and thus will not work with astro-pagefind integration.",
                    );
                    return;
                }

                if (config.adapter?.name.startsWith("@astrojs/vercel")) {
                    outDir = fileURLToPath(new URL(".vercel/output/static/", config.root));
                } else if (config.adapter?.name === "@astrojs/cloudflare") {
                    outDir = fileURLToPath(new URL(config.base?.replace(/^\//, ""), config.outDir));
                } else if (config.adapter?.name === "@astrojs/node" && config.output === "hybrid") {
                    outDir = fileURLToPath(config.build.client);
                } else {
                    outDir = fileURLToPath(config.outDir);
                }
            },
            "astro:build:done": ()=>{
                return astroBuildDone(options,outDir);
            }
        },
    }
});
